@@ -17,9 +17,7 @@
  * The GPL is the license under which I have extracted gs386.S
  * from Ghostscript and included it with this program.  The
  * 'Ghostscript GPL' referred to in that file is evidently
- * the ver.2 GPL, as seen in gs261/COPYING.  If Aladdin or Torek
- * has any problem with this redistribution I will happily adjust
- * things to suit, everyone else is referred to /dev/null.
+ * the ver.2 GPL, as seen in gs261/COPYING.
  */
 
 /* This program is based on a 1985 version of Chris Torek's imagen1
@@ -662,7 +660,7 @@ register char **argv;
     if (isatty (fileno (stdin)))
 	error (1, 0, "input from ttys is expressly forbidden!");
 
-    pkfonts = getenv ("pkfonts");
+    pkfonts = getenv ("PKFONTS");
     if (pkfonts == 0)
 	pkfonts = "";
 
@@ -728,7 +726,7 @@ Flags (with default values)\n\
     -x-offset 0.0	shift output left or right (inches)\n\
     -y-offset 0.0	shift output up or down (inches)\n\
     -magnification 1.0	increase or decrease size\n");
-  exit (1);
+  exit (2);
 }
 
 
