@@ -54,7 +54,7 @@ char *fmt;
     putc ('\n', stderr);
     fflush (stderr);		/* just in case */
     if (quit)
-	exit (quit);
+	exit (2);
 }
 
 #endif lint
